"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GameData = exports.PlayerDataFlags = void 0;
const Networkable_1 = require("../Networkable");
var PlayerDataFlags;
(function (PlayerDataFlags) {
    PlayerDataFlags[PlayerDataFlags["Disconnected"] = 1] = "Disconnected";
    PlayerDataFlags[PlayerDataFlags["Impostor"] = 2] = "Impostor";
    PlayerDataFlags[PlayerDataFlags["Dead"] = 4] = "Dead";
})(PlayerDataFlags = exports.PlayerDataFlags || (exports.PlayerDataFlags = {}));
class GameData extends Networkable_1.Networkable {
    constructor(stage, netid, data) {
        super(stage, netid, data);
        this.classname = "GameData";
    }
    Deserialize(reader, spawn = false) {
        if (spawn) {
            this.dirtyBit = 0;
            this.players = new Map;
        }
        const num_players = spawn ? reader.upacked() : reader.uint8();
        for (let i = 0; i < num_players; i++) {
            const data = GameData.readPlayerData(reader);
            this.players.set(data.playerId, data);
        }
    }
    Serialize(writer, spawn = false) {
        if (spawn) {
            writer.upacked(this.players.size);
        }
        else {
            writer.upacked(this.players.size);
        }
        for (const [, player] of this.players) {
            writer.uint8(player.playerId);
            writer.string(player.name);
            writer.upacked(player.color);
            writer.upacked(player.hat);
            writer.upacked(player.pet);
            writer.upacked(player.skin);
            writer.upacked(player.flags);
            for (let i = 0; i < player.tasks.length; i++) {
                const task = player.tasks[i];
                writer.upacked(task.taskIdx);
                writer.bool(task.completed);
            }
        }
    }
    static readPlayerData(reader) {
        const data = {};
        data.playerId = reader.uint8();
        data.name = reader.string();
        data.color = reader.upacked();
        data.hat = reader.upacked();
        data.pet = reader.upacked();
        data.skin = reader.upacked();
        data.flags = reader.byte();
        data.tasks = [];
        const num_tasks = reader.uint8();
        for (let i = 0; i < num_tasks; i++) {
            const taskIdx = reader.upacked();
            const completed = reader.bool();
            data.tasks.push({ taskIdx, completed });
        }
        return data;
    }
}
exports.GameData = GameData;
GameData.classname = "GameData";
