"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MeetingHud = exports.VoteState = void 0;
const Networkable_1 = require("../Networkable");
var VoteState;
(function (VoteState) {
    VoteState[VoteState["VotedFor"] = 15] = "VotedFor";
    VoteState[VoteState["DidReport"] = 32] = "DidReport";
    VoteState[VoteState["DidVote"] = 64] = "DidVote";
    VoteState[VoteState["IsDead"] = 128] = "IsDead";
})(VoteState = exports.VoteState || (exports.VoteState = {}));
class MeetingHud extends Networkable_1.Networkable {
    constructor(stage, netid, data) {
        super(stage, netid, data);
        this.classname = "MeetingHud";
    }
    Deserialize(reader, spawn = false) {
        if (spawn) {
            this.dirtyBit = 0;
            this.players = new Map;
            for (let i = 0; i < this.players.size; i++) {
                this.players.set(i, MeetingHud.readPlayerState(reader));
            }
        }
        else {
            const mask = reader.upacked();
            for (let i = 0; i < this.players.size; i++) {
                if (mask & (1 << i)) {
                    this.players.set(i, MeetingHud.readPlayerState(reader));
                }
            }
        }
    }
    Serialize(writer, spawn = false) {
        if (spawn) {
            for (const [, player] of this.players) {
                writer.upacked(player.state);
            }
        }
        else {
            writer.upacked(this.dirtyBit);
            for (const [playerId, player] of this.players) {
                if (this.dirtyBit & (1 << playerId)) {
                    writer.upacked(player.state);
                }
            }
        }
    }
    static readPlayerState(reader) {
        const voteState = {
            state: reader.byte(),
            get voted() {
                return (this.state & VoteState.VotedFor) - 1;
            }
        };
        return voteState;
    }
}
exports.MeetingHud = MeetingHud;
MeetingHud.classname = "MeetingHud";
