"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Int2Code = exports.Code2Int = exports.V2Int2Code = exports.V2Code2Int = exports.V1Int2Code = exports.V1Code2Int = void 0;
function V1Code2Int(code) {
    const a = code.charCodeAt(0) & 0xFF;
    const b = code.charCodeAt(1) & 0xFF;
    const c = code.charCodeAt(2) & 0xFF;
    const d = code.charCodeAt(3) & 0xFF;
    return a << 24 | b << 16 | c << 8 | d;
}
exports.V1Code2Int = V1Code2Int;
function V1Int2Code(bytes) {
    const a = String.fromCharCode((bytes >> 24) & 0xFF);
    const b = String.fromCharCode((bytes >> 16) & 0xFF);
    const c = String.fromCharCode((bytes >> 8) & 0xFF);
    const d = String.fromCharCode(bytes & 0xFF);
    return a + b + c + d;
}
exports.V1Int2Code = V1Int2Code;
const V2 = "QWXRTYLPESDFGHUJKZOCVBINMA";
const V2Map = [25, 21, 19, 10, 8, 11, 12, 13, 22, 15, 16, 6, 24, 23, 18, 7, 0, 3, 9, 4, 14, 20, 1, 2, 5, 17];
function V2Code2Int(code) {
    const a = V2Map[code.charCodeAt(0) - 65];
    const b = V2Map[code.charCodeAt(1) - 65];
    const c = V2Map[code.charCodeAt(2) - 65];
    const d = V2Map[code.charCodeAt(3) - 65];
    const e = V2Map[code.charCodeAt(4) - 65];
    const f = V2Map[code.charCodeAt(5) - 65];
    const one = (a + 26 * b) & 0x3FF;
    const two = (c + 26 * (d + 26 * (e + 26 * f)));
    return (one | ((two << 10) & 0x3FFFFC00) | 0x80000000);
}
exports.V2Code2Int = V2Code2Int;
function V2Int2Code(bytes) {
    const a = bytes & 0x3FF;
    const b = (bytes >> 10) & 0xFFFFF;
    return V2[a % 26] +
        V2[~~(a / 26)] +
        V2[b % 26] +
        V2[~~(b / 26 % 26)] +
        V2[~~(b / (26 * 26) % 26)] +
        V2[~~(b / (26 * 26 * 26) % 26)];
}
exports.V2Int2Code = V2Int2Code;
function Code2Int(code) {
    if (code.length === 6) {
        return V2Code2Int(code);
    }
    else if (code.length === 4) {
        return V1Code2Int(code);
    }
    else {
        return 0;
    }
}
exports.Code2Int = Code2Int;
function Int2Code(bytes) {
    if (bytes < 0) {
        return V2Int2Code(bytes);
    }
    else {
        return V1Int2Code(bytes);
    }
}
exports.Int2Code = Int2Code;
