"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextBuilder = void 0;
const hex = (h) => h.toString(16).padStart(2, "0");
class TextBuilder {
    constructor() {
        this._str = "";
    }
    get str() {
        return this._str;
    }
    /**
     * Write plain text.
     */
    text(str) {
        this._str += str;
        return this;
    }
    /**
     * Create a text tag (color, link)
     */
    tag(content) {
        this._str += "[" + content + "]";
        return this;
    }
    color(r, g, b, a) {
        if (typeof r === "string") {
            if (!/^[a-fA-F0-9]+$/.test(r)) {
                return this.color(r.replace(/[^a-fA-F0-9]/g, "0"));
            }
            const hexclr = r.padStart(2, "0");
            this.tag(hexclr);
        }
        else if (typeof r === "number") {
            const hexclr = hex(r) + hex(g) + hex(b) + hex(a);
            this.tag(hexclr);
        }
        return this;
    }
    /**
     * Clear all styles (color, link).
     */
    clear() {
        this.tag("");
        return this;
    }
    /**
     * Write a clickable link.
     * @param url A URL to link to, must begin with http.
     */
    link(url) {
        if (url.startsWith("http")) {
            this._str += "[" + url + "]";
        }
        else {
            throw new Error("TextBuilder: Invalid URL (must start with http).");
        }
        return this;
    }
}
exports.TextBuilder = TextBuilder;
